//---------------------------------------------------------------------------

#ifndef NIST_Type_8_data_converter_main_formH
#define NIST_Type_8_data_converter_main_formH
//---------------------------------------------------------------------------
#include <System.Classes.hpp>
#include <Vcl.Controls.hpp>
#include <Vcl.StdCtrls.hpp>
#include <Vcl.Forms.hpp>
#include <Vcl.ExtCtrls.hpp>

// File access routines
#include <stdio.h>
#include <fcntl.h>
#include <io.h>



//WSQ image library declaration of functions

typedef int (*RegisterWSQ)();
typedef HBITMAP (*CreateBMPFromFile)( const char *filename);
typedef int (*SaveBMPToFile)(HBITMAP hBitmap, const char *filename, int filetype);
typedef HBITMAP (*CreateBMPFromWSQByteArray)(unsigned char *input_wsq_byte_array, int size_of_input_wsq_byte_array);
typedef int (*SaveWSQByteArrayToImageFile)(unsigned char *input_wsq_byte_array, int size_of_input_wsq_byte_array, const char *filename, int filetype);
typedef int (*SetShowFilePropertiesDialog)(int file_properties_dialog);
typedef int (*ShowFileConverter)();
typedef int (*WSQ_decode_stream)(unsigned char *input_data_stream, const int input_stream_length, unsigned char **output_data_stream, int *width, int *height, int *ppi, char **comment_text);
typedef int (*WSQ_encode_stream)(unsigned char *input_data_stream, const int width, const int height, const double bitrate, const int ppi, char *comment_text, unsigned char **output_data_stream, int *output_stream_length);
typedef HBITMAP (*ConvertHBITMAPtoGrayScale256)(HBITMAP hBitmap);
typedef int (*SaveHBITMAPtoFileAsGrayScale256BMP)(HBITMAP hBitmap, const char *filename);

typedef HBITMAP (*CreateHBITMAPfromNISTType8BinaryField)(int type8_width, int type8_height, int type8_compression_type, unsigned char* type8_input_byte_array, int type8_input_byte_array_size);

//typedef HBITMAP (*CreateHBITMAPfromNISTType8UncompressedBinaryField)(int type8_width, int type8_height, unsigned char* type8_input_byte_array, int type8_input_byte_array_size);
//typedef HBITMAP (*CreateHBITMAPfromNISTType8CompressedBinaryField)(int type8_width, int type8_height, unsigned char* type8_input_byte_array, int type8_input_byte_array_size);

typedef unsigned char* (*CreateNISTType8BinaryFieldfromHBITMAP)(HBITMAP input_HBITMAP, int type8_compression_type);

//typedef unsigned char* (*CreateNISTType8UncompressedBinaryFieldfromHBITMAP)(HBITMAP input_HBITMAP);
//typedef unsigned char* (*CreateNISTType8CompressedBinaryFieldfromHBITMAP)(HBITMAP input_HBITMAP);

typedef int (*ReadType8DataCompressionType)();
typedef int (*ReadType8DataWidth)();
typedef int (*ReadType8DataHeight)();
typedef int (*ReadSizeOfNISTType8BinaryField)();
typedef int (*SetNISTType8ImageColorInversion)(int in_uncompressed_type8_image_inverted, int out_uncompressed_type8_image_inverted, int in_compressed_type8_image_inverted, int out_compressed_type8_image_inverted);


typedef char*(*GenerateSerialNumber)();
typedef (*UnlockWSQLibrary)(const char* authorization_code);



RegisterWSQ pRegisterWSQ;
CreateBMPFromFile  pCreateBMPFromFile;
SaveBMPToFile  pSaveBMPToFile;
CreateBMPFromWSQByteArray pCreateBMPFromWSQByteArray;
SaveWSQByteArrayToImageFile pSaveWSQByteArrayToImageFile;
SetShowFilePropertiesDialog pSetShowFilePropertiesDialog;
ShowFileConverter pShowFileConverter;
WSQ_decode_stream pWSQ_decode_stream;
WSQ_encode_stream pWSQ_encode_stream;
ConvertHBITMAPtoGrayScale256 pConvertHBITMAPtoGrayScale256;
SaveHBITMAPtoFileAsGrayScale256BMP pSaveHBITMAPtoFileAsGrayScale256BMP;
CreateHBITMAPfromNISTType8BinaryField pCreateHBITMAPfromNISTType8BinaryField;
//CreateHBITMAPfromNISTType8UncompressedBinaryField pCreateHBITMAPfromNISTType8UncompressedBinaryField;
//CreateHBITMAPfromNISTType8CompressedBinaryField pCreateHBITMAPfromNISTType8CompressedBinaryField;
CreateNISTType8BinaryFieldfromHBITMAP pCreateNISTType8BinaryFieldfromHBITMAP;
//CreateNISTType8UncompressedBinaryFieldfromHBITMAP pCreateNISTType8UncompressedBinaryFieldfromHBITMAP;
//CreateNISTType8CompressedBinaryFieldfromHBITMAP pCreateNISTType8CompressedBinaryFieldfromHBITMAP;
ReadType8DataCompressionType pReadType8DataCompressionType;
ReadType8DataWidth pReadType8DataWidth;
ReadType8DataHeight pReadType8DataHeight;
ReadSizeOfNISTType8BinaryField pReadSizeOfNISTType8BinaryField;

SetNISTType8ImageColorInversion pSetNISTType8ImageColorInversion;


GenerateSerialNumber pGenerateSerialNumber;
UnlockWSQLibrary pUnlockWSQLibrary;


HINSTANCE hWSQ_library;




//---------------------------------------------------------------------------
class TForm1 : public TForm
{
__published:	// IDE-managed Components
	TButton *ConvertToType8Button;
	TImage *OutputImage;
	TButton *ConvertFromType8Button;
	TEdit *EditWidth;
	TEdit *EditHeight;
	TLabel *LabelWidth;
	TLabel *LabelHeight;
	TComboBox *ComboBoxCompression;
	TButton *OpenButton;
	TButton *SaveButton;
	TScrollBox *ScrollBox1;
	void __fastcall ConvertToType8ButtonClick(TObject *Sender);
	void __fastcall ConvertFromType8ButtonClick(TObject *Sender);
	void __fastcall OpenButtonClick(TObject *Sender);
	void __fastcall SaveButtonClick(TObject *Sender);
private:	// User declarations
public:		// User declarations
	__fastcall TForm1(TComponent* Owner);


   int size_of_type8_binary_field;
   int type8_image_width, type8_image_height;
   int type8_image_compression_type;
   String type8_image_size_txt_file;
   String save_type8_binary_field_filename;

   unsigned char *type8_input_data_stream, *type8_output_data_stream;
   int type8_input_stream_length, type8_output_stream_length;

   int ret, n;
   FILE *infp, *outfp, *image_size_txt_filefp;
   int handle;
   char* type8_save_filename_with_extension;


   HBITMAP hBitmap;// = NULL;


};
//---------------------------------------------------------------------------
extern PACKAGE TForm1 *Form1;
//---------------------------------------------------------------------------
#endif
